searchData={"items":[{"type":"module","title":"Cldr.List","doc":"Cldr module to formats lists.\n\nIf we have a list of days like `[\"Monday\", \"Tuesday\", \"Wednesday\"]`\nthen we can format that list for a given locale by:\n\n    iex> Cldr.List.to_string([\"Monday\", \"Tuesday\", \"Wednesday\"], MyApp.Cldr, locale: \"en\")\n    {:ok, \"Monday, Tuesday, and Wednesday\"}","ref":"Cldr.List.html"},{"type":"function","title":"Cldr.List.intersperse/3","doc":"Intersperces a list elements into a list format according to the list\npattern rules for a locale.\n\nThis function can be helpful when creating a list from `Phoenix`\nsafe strings which are of the format `{:safe, \"some string\"}`","ref":"Cldr.List.html#intersperse/3"},{"type":"function","title":"Arguments - Cldr.List.intersperse/3","doc":"* `list` is any list of of terms\n\n* `options` is a keyword list","ref":"Cldr.List.html#intersperse/3-arguments"},{"type":"function","title":"Options - Cldr.List.intersperse/3","doc":"* `:locale` is any configured locale. See `Cldr.known_locale_names/1`. The default\n  is `locale: Cldr.get_locale/1`\n\n* `:format` is atom returned by\n  `Cldr.List.known_list_formats/0`. The default is `:standard`","ref":"Cldr.List.html#intersperse/3-options"},{"type":"function","title":"Examples - Cldr.List.intersperse/3","doc":"iex> Cldr.List.intersperse([\"a\", \"b\", \"c\"], MyApp.Cldr, locale: \"en\")\n    {:ok, [\"a\", \", \", \"b\", \", and \", \"c\"]}\n\n    iex> Cldr.List.intersperse([\"a\", \"b\", \"c\"], MyApp.Cldr, locale: \"en\", format: :unit_narrow)\n    {:ok, [\"a\", \" \", \"b\", \" \", \"c\"]}\n\n    iex> Cldr.List.intersperse([\"a\", \"b\", \"c\"], MyApp.Cldr, locale: \"fr\")\n    {:ok, [\"a\", \", \", \"b\", \" et \", \"c\"]}\n\n    iex> Cldr.List.intersperse([1,2,3,4,5,6], MyApp.Cldr)\n    {:ok, [1, \", \", 2, \", \", 3, \", \", 4, \", \", 5, \", and \", 6]}\n\n    iex> Cldr.List.intersperse([\"a\"], MyApp.Cldr)\n    {:ok, [\"a\"]}\n\n    iex> Cldr.List.intersperse([1,2], MyApp.Cldr)\n    {:ok, [1, \" and \", 2]}","ref":"Cldr.List.html#intersperse/3-examples"},{"type":"function","title":"Cldr.List.intersperse!/3","doc":"Formats a list using `intersperse/2` but raises if there is\nan error.","ref":"Cldr.List.html#intersperse!/3"},{"type":"function","title":"Examples - Cldr.List.intersperse!/3","doc":"iex> Cldr.List.intersperse!([\"a\", \"b\", \"c\"], MyApp.Cldr, locale: \"en\")\n    [\"a\", \", \", \"b\", \", and \", \"c\"]\n\n    iex> Cldr.List.intersperse!([\"a\", \"b\", \"c\"], MyApp.Cldr, locale: \"en\", format: :unit_narrow)\n    [\"a\", \" \", \"b\", \" \", \"c\"]","ref":"Cldr.List.html#intersperse!/3-examples"},{"type":"function","title":"Cldr.List.known_list_formats/0","doc":"Return the list of known list formats.","ref":"Cldr.List.html#known_list_formats/0"},{"type":"function","title":"Example - Cldr.List.known_list_formats/0","doc":"iex> Cldr.List.known_list_formats()\n    [:or, :or_narrow, :or_short, :standard, :standard_narrow,\n      :standard_short, :unit, :unit_narrow, :unit_short]","ref":"Cldr.List.html#known_list_formats/0-example"},{"type":"function","title":"Cldr.List.known_list_styles/0","doc":"","ref":"Cldr.List.html#known_list_styles/0"},{"type":"function","title":"Cldr.List.list_formats_for/2","doc":"Returns the formats of list patterns available for a locale.\n\nReturns a list of `atom`s of of the list formats that are\navailable in CLDR for a locale.","ref":"Cldr.List.html#list_formats_for/2"},{"type":"function","title":"Example - Cldr.List.list_formats_for/2","doc":"iex> Cldr.List.list_formats_for(\"en\", MyApp.Cldr)\n    [:or, :or_narrow, :or_short, :standard, :standard_narrow,\n      :standard_short, :unit, :unit_narrow, :unit_short]","ref":"Cldr.List.html#list_formats_for/2-example"},{"type":"function","title":"Cldr.List.list_patterns_for/2","doc":"Returns the list patterns for a locale.\n\nList patterns provide rules for combining multiple\nitems into a language format appropriate for a locale.","ref":"Cldr.List.html#list_patterns_for/2"},{"type":"function","title":"Example - Cldr.List.list_patterns_for/2","doc":"iex> Cldr.List.list_patterns_for \"en\", MyApp.Cldr\n    %{\n      or: %{\n        2 => [0, \" or \", 1],\n        end: [0, \", or \", 1],\n        middle: [0, \", \", 1],\n        start: [0, \", \", 1]\n      },\n      or_narrow: %{\n        2 => [0, \" or \", 1],\n        end: [0, \", or \", 1],\n        middle: [0, \", \", 1],\n        start: [0, \", \", 1]\n      },\n      or_short: %{\n        2 => [0, \" or \", 1],\n        end: [0, \", or \", 1],\n        middle: [0, \", \", 1],\n        start: [0, \", \", 1]\n      },\n      standard: %{\n        2 => [0, \" and \", 1],\n        end: [0, \", and \", 1],\n        middle: [0, \", \", 1],\n        start: [0, \", \", 1]\n      },\n      standard_narrow: %{\n        2 => [0, \", \", 1],\n        end: [0, \", \", 1],\n        middle: [0, \", \", 1],\n        start: [0, \", \", 1]\n      },\n      standard_short: %{\n        2 => [0, \" & \", 1],\n        end: [0, \", & \", 1],\n        middle: [0, \", \", 1],\n        start: [0, \", \", 1]\n      },\n      unit: %{\n        2 => [0, \", \", 1],\n        end: [0, \", \", 1],\n        middle: [0, \", \", 1],\n        start: [0, \", \", 1]\n      },\n      unit_narrow: %{\n        2 => [0, \" \", 1],\n        end: [0, \" \", 1],\n        middle: [0, \" \", 1],\n        start: [0, \" \", 1]\n      },\n      unit_short: %{\n        2 => [0, \", \", 1],\n        end: [0, \", \", 1],\n        middle: [0, \", \", 1],\n        start: [0, \", \", 1]\n      }\n    }","ref":"Cldr.List.html#list_patterns_for/2-example"},{"type":"function","title":"Cldr.List.list_styles_for/2","doc":"","ref":"Cldr.List.html#list_styles_for/2"},{"type":"function","title":"Cldr.List.to_string/3","doc":"Formats a list into a string according to the list pattern rules for a locale.","ref":"Cldr.List.html#to_string/3"},{"type":"function","title":"Arguments - Cldr.List.to_string/3","doc":"* `list` is any list of of terms that can be passed through `Kernel.to_string/1`\n\n* `options` is a keyword list","ref":"Cldr.List.html#to_string/3-arguments"},{"type":"function","title":"Options - Cldr.List.to_string/3","doc":"* `:locale` is any configured locale. See `Cldr.known_locales()`. The default\n  is `locale: Cldr.get_locale/1`\n\n* `:format` is one of those returned by\n  `Cldr.List.known_list_formats/0`. The default is `format: :standard`","ref":"Cldr.List.html#to_string/3-options"},{"type":"function","title":"Examples - Cldr.List.to_string/3","doc":"iex> Cldr.List.to_string([\"a\", \"b\", \"c\"], MyApp.Cldr, locale: \"en\")\n    {:ok, \"a, b, and c\"}\n\n    iex> Cldr.List.to_string([\"a\", \"b\", \"c\"], MyApp.Cldr, locale: \"en\", format: :unit_narrow)\n    {:ok, \"a b c\"}\n\n    iex> Cldr.List.to_string([\"a\", \"b\", \"c\"], MyApp.Cldr, locale: \"fr\")\n    {:ok, \"a, b et c\"}\n\n    iex> Cldr.List.to_string([1,2,3,4,5,6], MyApp.Cldr)\n    {:ok, \"1, 2, 3, 4, 5, and 6\"}\n\n    iex> Cldr.List.to_string([\"a\"], MyApp.Cldr)\n    {:ok, \"a\"}\n\n    iex> Cldr.List.to_string([1,2], MyApp.Cldr)\n    {:ok, \"1 and 2\"}","ref":"Cldr.List.html#to_string/3-examples"},{"type":"function","title":"Cldr.List.to_string!/3","doc":"Formats a list using `to_string/2` but raises if there is\nan error.","ref":"Cldr.List.html#to_string!/3"},{"type":"function","title":"Examples - Cldr.List.to_string!/3","doc":"iex> Cldr.List.to_string!([\"a\", \"b\", \"c\"], MyApp.Cldr, locale: \"en\")\n    \"a, b, and c\"\n\n    iex> Cldr.List.to_string!([\"a\", \"b\", \"c\"], MyApp.Cldr, locale: \"en\", format: :unit_narrow)\n    \"a b c\"","ref":"Cldr.List.html#to_string!/3-examples"},{"type":"type","title":"Cldr.List.pattern_type/0","doc":"","ref":"Cldr.List.html#t:pattern_type/0"},{"type":"module","title":"Cldr.List.Backend","doc":"","ref":"Cldr.List.Backend.html"},{"type":"function","title":"Cldr.List.Backend.define_list_module/1","doc":"","ref":"Cldr.List.Backend.html#define_list_module/1"},{"type":"extras","title":"Cldr for Lists","doc":"# Cldr for Lists\n[![Hex.pm](https://img.shields.io/hexpm/v/ex_cldr_lists.svg)](https://hex.pm/packages/ex_cldr_lists)\n[![Hex.pm](https://img.shields.io/hexpm/dw/ex_cldr_lists.svg?)](https://hex.pm/packages/ex_cldr_lists)\n[![Hex.pm](https://img.shields.io/hexpm/l/ex_cldr_lists.svg)](https://hex.pm/packages/ex_cldr_lists)","ref":"readme.html"},{"type":"extras","title":"Introduction and Getting Started - Cldr for Lists","doc":"`ex_cldr_lists` is an add-on library for [ex_cldr](https://hex.pm/packages/ex_cldr) that provides localisation and formatting for lists.\n\n`Cldr` interprets the CLDR rules for list formatting in a locale-specific way.\n\n#","ref":"readme.html#introduction-and-getting-started"},{"type":"extras","title":"Configuration - Cldr for Lists","doc":"From [ex_cldr](https://hex.pm/packages/ex_cldr) version 2.0, a backend module must be defined into which the public API and the [CLDR](https://cldr.unicode.org) data is compiled.  See the [ex_cldr documentation](https://hexdocs.pm/ex_cldr/readme.html) for further information on configuration.\n\nIn the following examples we assume the presence of a module called `MyApp.Cldr` defined as:\n```elixir\ndefmodule MyApp.Cldr do\n  use Cldr, locales: [\"en\", \"fr\"], default_locale: \"en\"\nend\n```","ref":"readme.html#configuration"},{"type":"extras","title":"Installation - Cldr for Lists","doc":"Note that `:ex_cldr_lists` requires Elixir 1.5 or later.\n\nAdd `ex_lists` as a dependency to your `mix` project:\n\n    defp deps do\n      [\n        {:ex_cldr_lists, \"~> 2.0\"}\n      ]\n    end\n\nthen retrieve `ex_cldr_lists` from [hex](https://hex.pm/packages/ex_cldr_lists):\n\n    mix deps.get\n    mix deps.compile","ref":"readme.html#installation"},{"type":"extras","title":"Public API & Examples - Cldr for Lists","doc":"There are two common public API functions:\n\n* `MyApp.Cldr.List.to_string/2` & `MyApp.Cldr.List.to_string!/2` which take a list of terms and returns a string.  Each item in the list must be understood by `Kernel.to_string/1`\n\n* `MyApp.Cldr.List.intersperse/2` & `MyApp.Cldr.List.intersperse!/2` which takes a list of terms and returns a list interspersed within the list format. This function can be helpful when creating a list from `Phoenix` safe strings which are of the format `{:safe, \"some string\"}`\n\nFor help in `iex`:\n\n```elixir\niex> h MyApp.Cldr.List.to_string\niex> h MyApp.Cldr.List.intersperse\n```\n\n#","ref":"readme.html#public-api-examples"},{"type":"extras","title":"List Formatting - Cldr for Lists","doc":"```elixir\niex> MyApp.Cldr.List.list_formats_for \"en\"\n[:or, :standard, :standard_short, :unit, :unit_narrow, :unit_short]\n\niex> MyApp.Cldr.List.to_string([\"a\", \"b\", \"c\"], locale: \"en\")\n{:ok, \"a, b, and c\"}\n\niex> MyApp.Cldr.List.to_string([\"a\", \"b\", \"c\"], locale: \"en\", format: :or)\n{:ok, \"a, b, or c\"}\n\niex> MyApp.Cldr.List.to_string([\"a\", \"b\", \"c\"], locale: \"en\", format: :unit)\n{:ok, \"a, b, c\"}\n\niex> MyApp.Cldr.List.to_string!([\"a\", \"b\", \"c\"], locale: \"en\", format: :unit)\n\"a, b, c\"\n\niex> MyApp.Cldr.List.intersperse([\"a\", \"b\", \"c\"], locale: \"en\")\n{:ok, [\"a\", \", \", \"b\", \", and \", \"c\"]}\n\n```\n\n#","ref":"readme.html#list-formatting"},{"type":"extras","title":"List Formats - Cldr for Lists","doc":"List formats are referred to by a pattern style the standardises the way to reference different formats in a locale.  See `MyApp.Cldr.List.list_formats_for/1`.  For example:\n\n```elixir\niex> MyApp.Cldr.List.list_formats_for \"en\"\n[:standard, :standard_short, :unit, :unit_narrow, :unit_short]\n\niex> MyApp.Cldr.List.list_formats_for \"ru\"\n[:standard, :standard_short, :unit, :unit_narrow, :unit_short]\n\niex> MyApp.Cldr.List.list_formats_for \"th\"\n[:standard, :standard_short, :unit, :unit_narrow, :unit_short]\n```\n\n#","ref":"readme.html#list-formats"},{"type":"extras","title":"Known formats - Cldr for Lists","doc":"The common formats for a locale are:\n\n* :or,\n* :or_narrow,\n* :or_short,\n* :standard,\n* :standard_narrow,\n* :standard_short,\n* :unit,\n* :unit_narrow,\n* :unit_short\n\nThis list is not fixed or definitive, other formats may be present for a locale.\n\nThe definitions of these formats can be explored through `MyApp.Cldr.List.list_patterns_for/1`. For example:\n\n```elixir\niex> MyApp.Cldr.List.list_patterns_for \"fr\"\n%{standard: %{\"2\": \"{0} et {1}\", end: \"{0} et {1}\", middle: \"{0}, {1}\",\n    start: \"{0}, {1}\"},\n  standard_short: %{\"2\": \"{0} et {1}\", end: \"{0} et {1}\", middle: \"{0}, {1}\",\n    start: \"{0}, {1}\"},\n  unit: %{\"2\": \"{0} et {1}\", end: \"{0} et {1}\", middle: \"{0}, {1}\",\n    start: \"{0}, {1}\"},\n  unit_narrow: %{\"2\": \"{0} {1}\", end: \"{0} {1}\", middle: \"{0} {1}\",\n    start: \"{0} {1}\"},\n  unit_short: %{\"2\": \"{0} et {1}\", end: \"{0} et {1}\", middle: \"{0}, {1}\",\n    start: \"{0}, {1}\"}}\n```","ref":"readme.html#known-formats"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"Cldr_Lists v2.10.2 - Changelog","doc":"This is the changelog for Cldr_lists v2.10.2 released on November 2nd, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_lists/tags)\n\n#","ref":"changelog.html#cldr_lists-v2-10-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix compiler warnings on Elixir 1.16.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Lists v2.10.1 - Changelog","doc":"This is the changelog for Cldr_lists v2.10.1 released on September 6th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_lists/tags)\n\n#","ref":"changelog.html#cldr_lists-v2-10-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix tests that depended on map key order.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Lists v2.10.0 - Changelog","doc":"This is the changelog for Cldr_lists v2.10.0 released on February 21st, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_lists/tags)\n\n#","ref":"changelog.html#cldr_lists-v2-10-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Updates to [ex_cldr version 2.26.0](https://hex.pm/packages/ex_cldr/2.26.0) and [ex_cldr_numbers version 2.25.0](https://hex.pm/packages/ex_cldr_numbers/2.25.0) which use atoms for locale names and rbnf locale names. This is consistent with other elements of `t:Cldr.LanguageTag` where atoms are used when the cardinality of the data is fixed and relatively small and strings where the data is free format.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Lists v2.9.0 - Changelog","doc":"This is the changelog for Cldr_lists v2.9.0 released on October 27th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_lists/tags)\n\n#","ref":"changelog.html#cldr_lists-v2-9-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Updates to support [CLDR release 40](https://cldr.unicode.org/index/downloads/cldr-40) via [ex_cldr version 2.24](https://hex.pm/packages/ex_cldr/2.24.0)\n\n#","ref":"changelog.html#enhancements"},{"type":"extras","title":"Deprecations - Changelog","doc":"* Don't call deprecated `Cldr.Config.get_locale/2`, call `Cldr.Locale.Loader.get_locale/2` instead.\n\n* Don't call deprecated `Cldr.Config.known_locale_names/1`, call `Cldr.Locale.Loader.known_locale_names/1` instead.","ref":"changelog.html#deprecations"},{"type":"extras","title":"Cldr_Lists v2.9.0-rc.2 - Changelog","doc":"This is the changelog for Cldr_lists v2.9.0-rc.2 released on October 25th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_lists/tags)\n\n#","ref":"changelog.html#cldr_lists-v2-9-0-rc-2"},{"type":"extras","title":"Deprecations - Changelog","doc":"* Don't call deprecated `Cldr.Config.known_locale_names/1`, call `Cldr.Locale.Loader.known_locale_names/1` instead.","ref":"changelog.html#deprecations"},{"type":"extras","title":"Cldr_Lists v2.9.0-rc.1 - Changelog","doc":"This is the changelog for Cldr_lists v2.9.0-rc.1 released on October 24th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_lists/tags)\n\n#","ref":"changelog.html#cldr_lists-v2-9-0-rc-1"},{"type":"extras","title":"Deprecations - Changelog","doc":"* Don't call deprecated `Cldr.Config.get_locale/2`, call `Cldr.Locale.Loader.get_locale/2` instead.","ref":"changelog.html#deprecations"},{"type":"extras","title":"Cldr_Lists v2.9.0-rc.1 - Changelog","doc":"This is the changelog for Cldr_lists v2.9.0-rc.0 released on October 3rd, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_lists/tags)\n\n#","ref":"changelog.html#cldr_lists-v2-9-0-rc-1"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Support [CLDR 40](http://cldr.unicode.org/index/downloads/cldr-40)","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Lists v2.8.0 - Changelog","doc":"This is the changelog for Cldr_lists v2.8.0 released on April 8th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_lists/tags)\n\n#","ref":"changelog.html#cldr_lists-v2-8-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Support [CLDR 39](http://cldr.unicode.org/index/downloads/cldr-39)","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Lists v2.7.0 - Changelog","doc":"This is the changelog for Cldr_lists v2.7.0 released on November 1st, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_lists/tags)\n\n#","ref":"changelog.html#cldr_lists-v2-7-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Support [CLDR 38](http://cldr.unicode.org/index/downloads/cldr-38)","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Lists v2.6.1 - Changelog","doc":"This is the changelog for Cldr_lists v2.6.1 released on September 26th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_lists/tags)\n\n#","ref":"changelog.html#cldr_lists-v2-6-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Use `Cldr.default_backend!/0` instead of `Cldr.default_backend/0` if its available","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Lists v2.6.0 - Changelog","doc":"This is the changelog for Cldr_lists v2.6.0 released on July 1st, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_lists/tags)\n\n#","ref":"changelog.html#cldr_lists-v2-6-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Standardize on `:format` rather than `:style` for formatting options. This is part of an ongoing effort to standardise option naming across the CLDR libraries. Thanks to @Zurga for the collaboration. Closes #4.  This reverts the decision made in `ex_cldr_lists version 2.4.0`.\n\n* Deprecates `Cldr.List.list_styles_for/2` in favour of `Cldr.List.list_formats_for/2`\n\n* Updates to use `Cldr.locale_and_backend_from/{1, 2}` which normalizes extraction of backend and locale from parameters and options. As a result, also bump the minimum version of `ex_cldr_numbers` to `2.15`","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Lists v2.5.0 - Changelog","doc":"This is the changelog for Cldr_lists v2.5.0 released on May 4th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_lists/tags)\n\n#","ref":"changelog.html#cldr_lists-v2-5-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add implementation for the `Cldr.Chars` protocol which is used by `Cldr.to_string/1` and which is a drop-in replacement for `Kernel.to_string/1` with added default localization.\n\n* Depends upon [ex_cldr_numbers version 2.17](https://hex.pm/packages/ex_cldr_numbers/2.17.0) which encapsulates CLDR39 data.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Lists v2.4.0 - Changelog","doc":"This is the changelog for Cldr_lists v2.4.0 released on August 31st, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_lists/tags)\n\n#","ref":"changelog.html#cldr_lists-v2-4-0"},{"type":"extras","title":"Changes and deprecations - Changelog","doc":"* Prefer the keyword option `:style` over `:format` to specify the list style in `Cldr.List.to_string/3` and `Cldr.List.intersperse/3`.  The keyword `:format` is deprecated and will be removed in `ex_cldr_lists` version 3.0\n\n* Rename `Cldr.List.list_pattern_styles_for/2` to `Cldr.List.list_styles_for/2`. `Cldr.List.list_pattern_styles_for/2` will still operate and delegates to `Cldr.List.list_styles_for/2`.  It is now deprecated and will be removed in `ex_cldr_lists` 3.0.","ref":"changelog.html#changes-and-deprecations"},{"type":"extras","title":"Cldr_Lists v2.3.0 - Changelog","doc":"This is the changelog for Cldr_lists v2.3.0 released on August 29th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_lists/tags)\n\n#","ref":"changelog.html#cldr_lists-v2-3-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add `Cldr.List.known_list_styles/0`","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Lists v2.2.2 - Changelog","doc":"This is the changelog for Cldr_lists v2.2.2 released on August 23rd, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_lists/tags)\n\n#","ref":"changelog.html#cldr_lists-v2-2-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix `@spec` for `Cldr.List.to_string/3` and `Cldr.List.to_string!/3`","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Lists v2.2.1 - Changelog","doc":"This is the changelog for Cldr_lists v2.2.1 released on August 21st, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_lists/tags)\n\n#","ref":"changelog.html#cldr_lists-v2-2-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Replace `Cldr.get_current_locale/0` with `Cldr.get_locale/0` in docs\n\n* The option `:backend` to `Cldr.List.to_string/3` will be used as the backend if provided\n\n* Fix dialyzer warnings","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Lists v2.2.0 - Changelog","doc":"This is the changelog for Cldr_lists v2.2.0 released on March 28th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_lists/tags)\n\n#","ref":"changelog.html#cldr_lists-v2-2-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Updates to [CLDR version 35.0.0](http://cldr.unicode.org/index/downloads/cldr-35) released on March 27th 2019.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Lists v2.1.0 - Changelog","doc":"This is the changelog for Cldr_lists v2.1.0 released on March 23rd, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_lists/tags)\n\n#","ref":"changelog.html#cldr_lists-v2-1-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Support `Cldr.default_backend/0` and apply it as the default for functions in `Cldr.List`","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Lists v2.0.2 - Changelog","doc":"This is the changelog for Cldr_lists v2.0.2 released on March 20th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_lists/tags)\n\n#","ref":"changelog.html#cldr_lists-v2-0-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix dialyzer warnings","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Lists v2.0.1 - Changelog","doc":"This is the changelog for Cldr_lists v2.0.1 released on March 15th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_lists/tags)\n\n#","ref":"changelog.html#cldr_lists-v2-0-1"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Makes generation of documentation for backend modules optional.  This is implemented by the `:generate_docs` option to the backend configuration.  The default is `true`. For example:\n\n```\ndefmodule MyApp.Cldr do\n  use Cldr,\n    default_locale: \"en-001\",\n    locales: [\"en\", \"ja\"],\n    gettext: MyApp.Gettext,\n    generate_docs: false\nend\n```","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Lists v2.0.0 - Changelog","doc":"This is the changelog for Cldr_lists v2.0.0 released on November 24th, 2018.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_lists/tags)\n\n#","ref":"changelog.html#cldr_lists-v2-0-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Move to a backend module structure with [ex_cldr](https://hex.pm/packages/ex_cldr) version 2.0\n* Add `Cldr.List.intersperse/3`.  Thanks to @lostkobrakai.  Closes #2.","ref":"changelog.html#enhancements"},{"type":"extras","title":"LICENSE","doc":"","ref":"license.html"},{"type":"extras","title":"License - LICENSE","doc":"Copyright 2017 Kip Cole\n\nLicensed under the Apache License, Version 2.0 (the \"License\"); you may not use this file except in\ncompliance with the License. You may obtain a copy of the License at\n\n    http://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software distributed under the License\nis distributed on an \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\nimplied. See the License for the specific language governing permissions and limitations under the\nLicense.","ref":"license.html#license"}],"content_type":"text/markdown"}